==> haskell-libxml-sax-0.7.6-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libxml-sax.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   libxml-sax
version:                0.7.6
visibility:             public
id:                     libxml-sax-0.7.6-GqQei8cpHy97iZTbmudMOW
key:                    libxml-sax-0.7.6-GqQei8cpHy97iZTbmudMOW
license:                MIT
maintainer:             jmillikin@gmail.com
author:                 John Millikin
stability:              experimental
homepage:               https://git.singpolyma.net/haskell-libxml-sax
synopsis:               Bindings for the libXML2 SAX interface
category:               Foreign, Text, XML, Parsing
abi:                    9ac3424bbf69352e3b506c4e360f3540
exposed:                True
exposed-modules:        Text.XML.LibXML.SAX
import-dirs:            /usr/lib/ghc-9.4.8/site-local/libxml-sax-0.7.6
library-dirs:           /usr/lib/ghc-9.4.8/site-local/libxml-sax-0.7.6
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/libxml-sax-0.7.6
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-libxml-sax
hs-libraries:           HSlibxml-sax-0.7.6-GqQei8cpHy97iZTbmudMOW
extra-libraries:        xml2 xml2
extra-libraries-static:
    xml2 m z lzma pthread icui18n icuuc icudata pthread m

include-dirs:           /usr/include/libxml2
depends:
    base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
    xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25

haddock-interfaces:     /usr/share/doc/haskell-libxml-sax/html/libxml-sax.haddock
haddock-html:           /usr/share/doc/haskell-libxml-sax/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libxml-sax-0.7.6-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libxml-sax.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   libxml-sax
version:                0.7.6
visibility:             public
id:                     libxml-sax-0.7.6-OpnF9zX9cqFuI8teggju5
key:                    libxml-sax-0.7.6-OpnF9zX9cqFuI8teggju5
license:                MIT
maintainer:             jmillikin@gmail.com
author:                 John Millikin
stability:              experimental
homepage:               https://git.singpolyma.net/haskell-libxml-sax
synopsis:               Bindings for the libXML2 SAX interface
category:               Foreign, Text, XML, Parsing
abi:                    0d6720c46b68b0230641b5da581a62cc
exposed:                True
exposed-modules:        Text.XML.LibXML.SAX
import-dirs:            /usr/lib/ghc-9.4.8/site-local/libxml-sax-0.7.6
library-dirs:           /usr/lib/ghc-9.4.8/site-local/libxml-sax-0.7.6
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/libxml-sax-0.7.6
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-libxml-sax
hs-libraries:           HSlibxml-sax-0.7.6-OpnF9zX9cqFuI8teggju5
extra-libraries:        xml2 xml2
extra-libraries-static:
    xml2 m z lzma pthread icui18n icuuc icudata pthread m

include-dirs:           /usr/include/libxml2
depends:
    base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
    xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25

haddock-interfaces:     /usr/share/doc/haskell-libxml-sax/html/libxml-sax.haddock
haddock-html:           /usr/share/doc/haskell-libxml-sax/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
